pub(crate) struct NativeConnectionWrapper {
pub(crate) xlib: Xlib,
pub(crate) egl_display: *const c_void,
egl_display_is_owned: bool,
x11_display: *mut Display,
x11_display_is_owned: bool,
}Fields
xlib: Xlibegl_display: *const c_voidegl_display_is_owned: boolWhether or not this NativeConnectionWrapper created its EGLDisplay.
If true, the Drop handler is reponsible for cleaning it up.
x11_display: *mut Displayx11_display_is_owned: boolWhether or not this NativeConnectionWrapper created its X11 Display.
If true, the Drop handler is reponsible for cleaning it up.
Implementations
Sourceimpl NativeConnectionWrapper
impl NativeConnectionWrapper
pub(crate) fn lock_display(&self) -> DisplayGuard<'_>